==> ejc-businessplan-impl-3.0.0-20220225.070150-6-sources.jar: com/ejianc/business/record/bean/RecordOrgstructureEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目商务组织架构记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_busniessplan_orgstructure")
public class RecordOrgstructureEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="original_id")
    private java.lang.Long originalId; // 原始单据id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="operator_id")
    private java.lang.String operatorId; // 经办人id
    @TableField(value="operator_name")
    private java.lang.String operatorName; // 经办人名称
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_state")
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="contract_manage_member")
    private java.lang.String contractManageMember; // 合约管理
    @TableField(value="pre_settlement_member")
    private java.lang.String preSettlementMember; // 预结算
    @TableField(value="cost_manage_member")
    private java.lang.String costManageMember; // 成本管理岗
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="bus_manager")
    private java.lang.String busManager; // 项目商务经理
    @TableField(value="bus_manage_dep_manager")
    private java.lang.String busManageDepManager; // 商务管理部部门经理
    @TableField(value="bus_manage_dep")
    private java.lang.String busManageDep; // 项目商务管理部
    @TableField(value="allocate_personnel_num")
    private java.lang.Integer allocatePersonnelNum; // 配置人员数
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="recordOrgstructuredetailService",pidName = "mid")
    private List<RecordOrgstructuredetailEntity> recordOrgstructuredetailEntities = new ArrayList<>(); // 项目商务组织架构子表记录
    

    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.String getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.String operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 合约管理
     */
    public java.lang.String getContractManageMember() {
        return contractManageMember;
    }

    /**
     * 合约管理
     */
    public void setContractManageMember(java.lang.String contractManageMember) {
        this.contractManageMember = contractManageMember;
    }
    /**
     * 预结算
     */
    public java.lang.String getPreSettlementMember() {
        return preSettlementMember;
    }

    /**
     * 预结算
     */
    public void setPreSettlementMember(java.lang.String preSettlementMember) {
        this.preSettlementMember = preSettlementMember;
    }
    /**
     * 成本管理岗
     */
    public java.lang.String getCostManageMember() {
        return costManageMember;
    }

    /**
     * 成本管理岗
     */
    public void setCostManageMember(java.lang.String costManageMember) {
        this.costManageMember = costManageMember;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 项目商务经理
     */
    public java.lang.String getBusManager() {
        return busManager;
    }

    /**
     * 项目商务经理
     */
    public void setBusManager(java.lang.String busManager) {
        this.busManager = busManager;
    }
    /**
     * 商务管理部部门经理
     */
    public java.lang.String getBusManageDepManager() {
        return busManageDepManager;
    }

    /**
     * 商务管理部部门经理
     */
    public void setBusManageDepManager(java.lang.String busManageDepManager) {
        this.busManageDepManager = busManageDepManager;
    }
    /**
     * 项目商务管理部
     */
    public java.lang.String getBusManageDep() {
        return busManageDep;
    }

    /**
     * 项目商务管理部
     */
    public void setBusManageDep(java.lang.String busManageDep) {
        this.busManageDep = busManageDep;
    }
    /**
     * 配置人员数
     */
    public java.lang.Integer getAllocatePersonnelNum() {
        return allocatePersonnelNum;
    }

    /**
     * 配置人员数
     */
    public void setAllocatePersonnelNum(java.lang.Integer allocatePersonnelNum) {
        this.allocatePersonnelNum = allocatePersonnelNum;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    
    /**
     * 项目商务组织架构子表记录
     */
    public List<RecordOrgstructuredetailEntity> getRecordOrgstructuredetailEntities() {
        return recordOrgstructuredetailEntities;
    }

    /**
     * 项目商务组织架构子表记录
     */
    public void setRecordOrgstructuredetailEntities(List<RecordOrgstructuredetailEntity> recordOrgstructuredetailEntities) {
        this.recordOrgstructuredetailEntities = recordOrgstructuredetailEntities;
    }
}

==> ejc-businessplan-impl-3.0.0-20241021.063348-193-sources.jar: com/ejianc/business/record/bean/RecordOrgstructureEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目商务组织架构记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_busniessplan_orgstructure")
public class RecordOrgstructureEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="original_id")
    private java.lang.Long originalId; // 原始单据id
    @TableField(value="orgstructure_code")
    private java.lang.String orgstructureCode; // 原始单据编码
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="operator_id")
    private java.lang.String operatorId; // 经办人id
    @TableField(value="operator_name")
    private java.lang.String operatorName; // 经办人名称
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_state")
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="contract_manage_member")
    private java.lang.String contractManageMember; // 合约管理
    @TableField(value="pre_settlement_member")
    private java.lang.String preSettlementMember; // 预结算
    @TableField(value="cost_manage_member")
    private java.lang.String costManageMember; // 成本管理岗
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="bus_manager")
    private java.lang.String busManager; // 项目商务经理
    @TableField(value="bus_manage_dep_manager")
    private java.lang.String busManageDepManager; // 商务管理部部门经理
    @TableField(value="bus_manage_dep")
    private java.lang.String busManageDep; // 项目商务管理部
    @TableField(value="allocate_personnel_num")
    private java.lang.Integer allocatePersonnelNum; // 配置人员数
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="recordOrgstructuredetailService",pidName = "mid")
    private List<RecordOrgstructuredetailEntity> orgstructuredetailEntities = new ArrayList<>(); // 项目商务组织架构子表记录
    

    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    public String getOrgstructureCode() {
        return orgstructureCode;
    }

    public void setOrgstructureCode(String orgstructureCode) {
        this.orgstructureCode = orgstructureCode;
    }

    /**
     * 原始单据id
     */

    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.String getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.String operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 合约管理
     */
    public java.lang.String getContractManageMember() {
        return contractManageMember;
    }

    /**
     * 合约管理
     */
    public void setContractManageMember(java.lang.String contractManageMember) {
        this.contractManageMember = contractManageMember;
    }
    /**
     * 预结算
     */
    public java.lang.String getPreSettlementMember() {
        return preSettlementMember;
    }

    /**
     * 预结算
     */
    public void setPreSettlementMember(java.lang.String preSettlementMember) {
        this.preSettlementMember = preSettlementMember;
    }
    /**
     * 成本管理岗
     */
    public java.lang.String getCostManageMember() {
        return costManageMember;
    }

    /**
     * 成本管理岗
     */
    public void setCostManageMember(java.lang.String costManageMember) {
        this.costManageMember = costManageMember;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 项目商务经理
     */
    public java.lang.String getBusManager() {
        return busManager;
    }

    /**
     * 项目商务经理
     */
    public void setBusManager(java.lang.String busManager) {
        this.busManager = busManager;
    }
    /**
     * 商务管理部部门经理
     */
    public java.lang.String getBusManageDepManager() {
        return busManageDepManager;
    }

    /**
     * 商务管理部部门经理
     */
    public void setBusManageDepManager(java.lang.String busManageDepManager) {
        this.busManageDepManager = busManageDepManager;
    }
    /**
     * 项目商务管理部
     */
    public java.lang.String getBusManageDep() {
        return busManageDep;
    }

    /**
     * 项目商务管理部
     */
    public void setBusManageDep(java.lang.String busManageDep) {
        this.busManageDep = busManageDep;
    }
    /**
     * 配置人员数
     */
    public java.lang.Integer getAllocatePersonnelNum() {
        return allocatePersonnelNum;
    }

    /**
     * 配置人员数
     */
    public void setAllocatePersonnelNum(java.lang.Integer allocatePersonnelNum) {
        this.allocatePersonnelNum = allocatePersonnelNum;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    
    /**
     * 项目商务组织架构子表记录
     */
    public List<RecordOrgstructuredetailEntity> getOrgstructuredetailEntities() {
        return orgstructuredetailEntities;
    }

    /**
     * 项目商务组织架构子表记录
     */
    public void setOrgstructuredetailEntities(List<RecordOrgstructuredetailEntity> orgstructuredetailEntities) {
        this.orgstructuredetailEntities = orgstructuredetailEntities;
    }
}
